/*
 * libdhcp pump compatibility API for anaconda -
 * only the pump symbols used by anaconda are defined.
 *
 ******************************************************************************
 * Original pump credits:
 * 
 * There are a bunch of folks who made this code possible. I'm sure I've missed
 * some in this list :-(
 *
 *  Alan Cox <alan@redhat.com>
 *  Bruce Beare <bbeare@cisco.com>
 *  David Blythe <blythe@routefree.com>
 *  Stephen Carville <carville@cpl.net>
 *  Guy Delamarter <delamart@pas.rochester.edu>
 *  Chris Johnson <cjohnson@mint.net>
 *  Michael Johnson <johnsonm@redhat.com>
 *  H. J. Lu <hjl@valinux.com>
 *  Kristof Petr <Petr@Kristof.CZ>
 *  Marco Pietrobono <pietrobo@pietrobo.com>
 *  Benjamin Reed <breed@cse.ucsc.edu>
 *  George Staikos <staikos@0wned.org>
 *  Jay Turner <jturner@redhat.com>
 *  Matt Wilson <msw@redhat.com>
 *  <aaron@schrab.com>
 *  <duanev@io.com>
 *  <dunham@cse.msu.edu>
 *  <safford@watson.ibm.com>
 *  weejock@ferret.lmh.ox.ac.uk
 *
 *******************************************************************************
 *
 * Copyright 1999-2001 Red Hat, Inc.
 *
 * All Rights Reserved.
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
 * OPEN GROUP BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
 * AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 * Except as contained in this notice, the name of Red Hat shall not be
 * used in advertising or otherwise to promote the sale, use or other dealings
 * in this Software without prior written authorization from Red Hat.
 *
 ******************************************************************************
 *
 * Copyright (C) 2006  Red Hat, Inc. All rights reserved.
 *
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions of
 * the GNU General Public License v.2, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY expressed or implied, including the implied warranties of
 * MERCHANTABILITY or FITNESS FOR A * PARTICULAR PURPOSE.  See the GNU General
 * Public License for more details.  You should have received a copy of the
 * GNU General Public License along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.  Any Red Hat trademarks that are incorporated in the
 * source code or documentation are not subject to the GNU General Public
 * License and may only be used or replicated with the express permission of
 * Red Hat, Inc.
 *
 * Red Hat Author(s): Jason Vas Dias
 *                    David Cantrell <dcantrell@redhat.com>
 *
 ******************************************************************************
 */

#ifndef H_NET
#define H_NET

#include <resolv.h>
#include "dhcp_nic.h"

typedef
enum pump_defs_e
{
    PUMP_INTFINFO_HAS_IP         = 1,
    PUMP_INTFINFO_HAS_IPV4_IP    = (1<<1),
    PUMP_INTFINFO_HAS_IPV6_IP    = (1<<2),
    PUMP_INTFINFO_HAS_IPV6_PREFIX= (1<<3),
    PUMP_INTFINFO_HAS_NETMASK    = (1<<4),
    PUMP_INTFINFO_HAS_BROADCAST  = (1<<5),
    PUMP_INTFINFO_HAS_NETWORK    = (1<<6),
    PUMP_INTFINFO_HAS_MTU        = (1<<7),
    PUMP_INTFINFO_HAS_NEXTSERVER = (1<<8),
    PUMP_INTFINFO_HAS_BOOTFILE   = (1<<9),
    /* room for more ... */
    PUMP_NETINFO_HAS_DNS         = (1<<16),
    PUMP_NETINFO_HAS_DOMAIN      = (1<<17),
    PUMP_NETINFO_HAS_GATEWAY     = (1<<18),
    PUMP_NETINFO_HAS_HOSTNAME    = (1<<19)
}   pump_defs_t;

/**
 * pump struct pumpNetIntf stripped down to fields
 * actually used by modern anaconda - plus some new 
 * fields.
 *
 * Code which uses any of the type ip_addr_t fields, 
 * that were type 'struct in_addr', now need to check
 * the fields' .sa_family and deal with either AF_INET
 * or AF_INET6 addresses (ip_addr_t is cast compatible 
 * with 'struct sockaddr_in' and 'struct sockaddr_in6').
 */
struct pumpNetIntf 
{
    char device[IF_NAMESIZE];

    ip_addr_t ip, ipv4, ipv6, netmask, broadcast, network,
              gateway, nextServer, dnsServers[MAXNS];

    /* set ipv6_prefixlen if 'ip' is IPv6 */
    int set, mtu, numDns, ipv6_prefixlen;

    /* dynamically allocated */
    char * bootFile, * hostname, * domain;

    /* the libdhcp NIC Library Handle */
    NLH_t nh;

    /* the libdhcp DHCP network interface configuration */
    DHCP_nic *dhcp_nic;
};

/**
 * pumpSetupInterface
 * Configure a network interface using static information or an already
 * obtained DHCP lease.
 *
 * @ifx The pump interface structure.
 */
extern char * pumpSetupInterface(struct pumpNetIntf * ifx);

/**
 * pump's pumpDhcpClassRun function.
 * The prototype is changed slightly to pass in libdhcp
 * control parameters and remove parameters not used
 * by anaconda.
 *
 * @ifx DHCP configuration to be stored (ifx->device must be set to the name
 *      of the interface to configure)
 * @hostname DHCP 'host-name' option to send
 * @vendor_class DHCP 'vendor-class-identifier' to send
 * @dhcp_preference DHCP policy (see dhcp_nic.h)
 * @dhcp_capability DHCP policy (see libdhcp.h)
 * @timeout time in seconds each client has to obtain a lease
 * @logger logging function pointer, NULL to disable
 * @max_log_priority if a logger was specific, the maximum priority to log
 */
extern char * pumpDhcpClassRun(struct pumpNetIntf * ifx,
                               char * hostname,
                               char * vendor_class,
                               DHCP_Preference dhcp_preference,
                               LIBDHCP_Capability dhcp_capability,
                               time_t timeout,
                               void (*logger)(void*,int,char*,va_list),
                               int max_log_priority);

extern char * pumpDisableInterface(char * device);
extern char * pumpEnableInterface(char * device);

#endif
